//  $Id: pfluid.hh,v 1.5 2010-05-08 14:07:34 madams Exp $
//  Author:             Mark F. Adams
// Copyright (c) 2003 by Mark F. Adams 
//  Filename:           pfeap.hh
//
#ifndef  __PFLUID_H__
#define  __PFLUID_H__

#include "pfeap.hh"

////////////////////////////////////////////////////////////////////////
//! Interface to Fluid application
////////////////////////////////////////////////////////////////////////
class FluidComponentIterface
{
public:
  virtual int SetUp( SurfaceMesh *smesh,double *dt ) = 0;
  virtual int Advance( double *dt, SurfaceMesh *smesh, const int timestep) = 0;
  virtual int Finalize() = 0;
};

////////////////////////////////////////////////////////////////////////
//! dummy fluid
////////////////////////////////////////////////////////////////////////
class pNoFluid : public FluidComponentIterface
{
public:
  pNoFluid(const PromComm &comm, PromOptions &opts, PromPerfMonitor &perf){}
  virtual ~pNoFluid(){}
  // methods
  int SetUp( SurfaceMesh *smesh, double *dt );
  int Advance( double *dt, SurfaceMesh *smesh ,const int timestep);
  int Finalize(){return 0;}
  // data
  
};

////////////////////////////////////////////////////////////////////////
//! no fluid
////////////////////////////////////////////////////////////////////////
class pVoidFluid : public FluidComponentIterface
{
public:
  pVoidFluid(const PromComm &, PromOptions &, PromPerfMonitor &){}
  virtual ~pVoidFluid(){}
  // methods
  int SetUp( SurfaceMesh *, double *dt){return 0;}
  int Advance( double *, SurfaceMesh *, const int timestep){return 0;}
  int Finalize(){return 0;}
};

////////////////////////////////////////////////////////////////////////
//!  Fluid application 
////////////////////////////////////////////////////////////////////////
class pFluid : public FluidComponentIterface
{
public:
  pFluid(const PromComm &comm, PromOptions &opts, PromPerfMonitor &perf);
  virtual ~pFluid();
  // methods
  int SetUp( SurfaceMesh *smesh, double *dt );
  int Advance( double *dt, SurfaceMesh *smesh, const int timestep);
  int Finalize(){return 0;}
  // data
  MPI_Comm m_fluidComm;
  PromOptions &options_;
  PromPerfMonitor &perf_mon_;
};

#endif //  __PFLUID_H__
